FontSettingButtons class

Font setting group

Inheritance

Constructors

FontSettingButtons({bool fontName = true, bool fontSize = true, bool fontSizeUnit = true})
const

Properties

fontName → bool
final
fontSize → bool
final
fontSizeUnit → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited