ParagraphButtons class

Paragraph group

Inheritance

Constructors

ParagraphButtons({bool alignLeft = true, bool alignCenter = true, bool alignRight = true, bool alignJustify = true, bool increaseIndent = true, bool decreaseIndent = true, bool textDirection = true, bool lineHeight = true, bool caseConverter = true})
const

Properties

alignCenter → bool
final
alignJustify → bool
final
alignLeft → bool
final
alignRight → bool
final
caseConverter → bool
final
decreaseIndent → bool
final
hashCode → int
The hash code for this object.
no setterinherited
increaseIndent → bool
final
lineHeight → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → bool
final

Methods

getIcons1() → List<Icon>
getIcons2() → List<Icon>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited