CustomDropdownButton<T> class

Inheritance

Constructors

CustomDropdownButton({Key? key, required List<CustomDropdownMenuItem<T>>? items, DropdownButtonBuilder? selectedItemBuilder, T? value, Widget? hint, Widget? disabledHint, ValueChanged<T?>? onChanged, VoidCallback? onTap, int elevation = 8, TextStyle? style, Widget? underline, Widget? icon, Color? iconDisabledColor, Color? iconEnabledColor, double iconSize = 24.0, bool isDense = false, bool isExpanded = false, double? itemHeight = kMinInteractiveDimension, Color? focusColor, FocusNode? focusNode, bool autofocus = false, Color? dropdownColor, double? menuMaxHeight, required DropdownMenuDirection menuDirection})

Properties

autofocus → bool
final
disabledHint → Widget?
final
final
elevation → int
final
focusColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → Widget?
final
icon → Widget?
final
iconDisabledColor → Color?
final
iconEnabledColor → Color?
final
iconSize → double
final
isDense → bool
final
isExpanded → bool
final
itemHeight → double?
final
items → List<CustomDropdownMenuItem<T>>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
final
onChanged → ValueChanged<T?>?
final
onTap → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBuilder → DropdownButtonBuilder?
final
style → TextStyle?
final
underline → Widget?
final
value → T?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _DropdownButtonState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited